#
# spec file for package avr-libc
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define into_sysroot 1
%define doc_vers 2.2.0
%if %{into_sysroot}
%define PREFIX /usr/avr/sys-root
%else
# FIXME:
# okay, FHS 2.2, if you forbid the obvious choices, can you also suggest a better place?
# avr-libc: "/usr/avr/{include,lib,...}" is not allowed anymore in FHS 2.2
# avr-libc: "/usr/local/avr/{include,lib,...}" is not allowed anymore in FHS 2.2
%define PREFIX %{_prefix}
%define PREFIX %{_prefix}/local
%endif

%{!?gcc_version: %define gcc_version 7}

Name:           avr-libc
Version:        2.2.1
Release:        1.1
Summary:        The C Runtime Library for AVR Microcontrollers
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            http://savannah.nongnu.org/projects/avr-libc
Source:         https://github.com/avrdudes/avr-libc/releases/download/%{name}-2_2_1-release/%{name}-%{version}.tar.bz2
Source1:        https://github.com/avrdudes/avr-libc/releases/download/%{name}-2_2_1-release/%{name}-%{version}.tar.bz2.sig
Source4:        https://avrdudes.github.io/avr-libc/%{name}-user-manual-%{doc_vers}.tar.bz2
Source6:        https://avrdudes.github.io/avr-libc/%{name}-user-manual-%{doc_vers}.pdf
# from http://pgp.mit.edu/pks/lookup?op=vindex&search=0x7E9EADC3030D34EB (Joerg Wunsch)
Source8:        %{name}.keyring
# from ?? - poor man's logic analyzer by 'jw'
Source9:        logicp-1.02.tgz
Source100:      %{name}-rpmlintrc
Patch0:         0001-Return-files-missed-in-the-release-tarball.patch
Patch1:         0002-dox_latex_header.tex-Add-to-EXTRA_DIST-969-1023.patch
Patch2:         0003-dox-api-Makefile.am-EXTRA_DIST-Add-filter-dox.sh-avr.patch
# required for ./bootstrap
BuildRequires:  autoconf
# required for ./bootstrap
BuildRequires:  automake
BuildRequires:  cross-avr-binutils
BuildRequires:  cross-avr-gcc%{gcc_version}-bootstrap
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  findutils
BuildRequires:  ghostscript
# required for autosetup -S git
BuildRequires:  git
BuildRequires:  netpbm
# required for ./bootstrap
BuildRequires:  python3
BuildRequires:  transfig
Recommends:     avr-example
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# does not depend on host arch. bnc#233520
BuildArch:      noarch

%description
The C runtime library for the AVR family of microcontrollers for use
with the GNU toolset (cross-avr-binutils, cross-avr-gcc, uisp, etc.).

%prep
# -S git is a workaround for:
# File avr-libc-logo-large.png: git binary diffs are not supported.
%autosetup -a4 -b9 -S git
cp -a %{SOURCE6} .

%build
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"
# required for 0002-dox_latex_header.tex-Add-to-EXTRA_DIST-969-1023.patch
#          and 0003-dox-api-Makefile.am-EXTRA_DIST-Add-filter-dox.sh-avr.patch
./bootstrap
./configure --prefix=%{PREFIX} --host=avr --mandir=%{PREFIX}/man
make %{?_smp_mflags} CC="avr-gcc -pipe" CCAS="avr-gcc -pipe"
# dox-html target builds man pages
make %{?_smp_mflags} -C doc/api dox-html

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
make -C doc/api DESTDIR=%{buildroot} install-dox-man %{?_smp_mflags}

mkdir -p %{buildroot}%{_docdir}/%{name}
cp -pr AUTHORS LICENSE NEWS README.md *.pdf %{buildroot}%{_docdir}/%{name}
cp -pr %{name}-user-manual-%{doc_vers} %{buildroot}%{_docdir}/%{name}/user-manual-%{doc_vers}
ln -s %{_docdir}/%{name}/user-manual-%{doc_vers} %{buildroot}/%{PREFIX}/share/doc/%{name}-%{version}/user-manual
ln -s %{PREFIX}/share/doc/%{name}-%{version}/examples %{buildroot}%{_docdir}/%{name}
cat >> %{buildroot}%{_docdir}/%{name}/user-manual.html <<EOF
<head><meta http-equiv="Refresh" content="0; user-manual-%{doc_vers}/index.html"></head>
<a href="user-manual-%{doc_vers}/pages.html">user-manual-%{doc_vers}/index.html</a>
EOF

mv %{buildroot}/%{PREFIX}/avr/* %{buildroot}/%{PREFIX}/
rm -Rf %{buildroot}/%{PREFIX}/avr

# do not run brp-strip-debug on our avr-elf objects.
export NO_BRP_STRIP_DEBUG=true

%fdupes %{buildroot}/%{PREFIX}
%fdupes -s %{buildroot}%{_docdir}/%{name}

%check
### selftest ###
cd ../logicp*
## how do we tell the linker that crt*.o is at a nonstandard location?
ln -s $RPM_BUILD_ROOT%PREFIX/lib/crtatt*.o .
ln -s $RPM_BUILD_ROOT%PREFIX/lib/avrtiny/crtatt*.o .
ln -s $RPM_BUILD_ROOT%PREFIX/lib/avr?/crtatm*.o .
make test CFLAGS="-Wall -g -Os -mint8 -I$RPM_BUILD_ROOT%PREFIX/include/ -L$RPM_BUILD_ROOT%PREFIX/lib/avr4" CPU=mega8 || true
make test CFLAGS="-Wall -g -Os -mint8 -I$RPM_BUILD_ROOT%PREFIX/include/ -L$RPM_BUILD_ROOT%PREFIX/lib/avr4" CPU=mega48 || true
make test CFLAGS="-Wall -g -Os -mint8 -I$RPM_BUILD_ROOT%PREFIX/include/ -L$RPM_BUILD_ROOT%PREFIX/lib/avr4" CPU=mega644 || true
make test CFLAGS="-Wall -g -Os -mint8 -I$RPM_BUILD_ROOT%PREFIX/include/ -L$RPM_BUILD_ROOT%PREFIX/lib"      CPU=tiny2313 || true
make test CFLAGS="-Wall -g -Os -mint8 -I$RPM_BUILD_ROOT%PREFIX/include/ -L$RPM_BUILD_ROOT%PREFIX/lib"      CPU=tiny4313 || true

%files
%defattr (-, root, root)
%doc %{_docdir}/%{name}
%if %{into_sysroot}
%dir %{PREFIX}
%{PREFIX}/*
%else
%{_prefix}/*
%endif
# %%doc /usr/share/man/man?/*.*

%changelog
* Fri Feb 21 2025 Matwey Kornilov <matwey.kornilov@gmail.com>
- update to 2.2.1
  * General:
  - Project moved to Github
  - Support for many new devices has been added, like devices from the
    AVR 0-series, 1-series, 2-series, AVR-Dx and AVR-Ex, but also for
    some older devices.
  - Parts of the user manual have been reworked, like the inline assembly
    Cookbook and the documentation of memory sections.
  - The multilib layout of the library, and what device belongs to which
    multilib variant, is no more hard coded in AVR-LibC but follows the
    compiler's multilib layout.
  * Improvements and additions:
  - Add support to new multilib layout / 64-bit [long] double compiler
    (Issues #642, #670)
  - Added support for new devices (Issue #824):
    ATtiny202 ATtiny204 ATtiny212 ATtiny214 ATtiny402 ATtiny404
    ATtiny406 ATtiny412 ATtiny414 ATtiny416 ATtiny417 ATtiny424
    ATtiny426 ATtiny427 ATtiny804 ATtiny806 ATtiny807 ATtiny814
    ATtiny816 ATtiny817 ATtiny824 ATtiny826 ATtiny827 ATtiny1604
    ATtiny1606 ATtiny1607 ATtiny1614 ATtiny1616 ATtiny1617 ATtiny1624
    ATtiny1626 ATtiny1627 ATtiny3214 ATtiny3216 ATtiny3217 ATtiny3224
    ATtiny3226 ATtiny3227 ATmega808 ATmega809 ATmega1608 ATmega1609
    ATmega3208 ATmega3209 ATmega4808 ATmega4809
  - Added support for AVR-Dx devices (Issue #881):
    AVR16DD14 AVR16DD20 AVR16DD28 AVR16DD32 AVR32DA28 AVR32DA32
    AVR32DA48 AVR32DB28 AVR32DB32 AVR32DB48 AVR32DD14 AVR32DD20
    AVR32DD28 AVR32DD32 AVR64DA28 AVR64DA32 AVR64DA48 AVR64DA64
    AVR64DB28 AVR64DB32 AVR64DB48 AVR64DB64 AVR64DD14 AVR64DD20
    AVR64DD28 AVR64DD32 AVR128DA28 AVR128DA32 AVR128DA48 AVR128DA64
    AVR128DB28 AVR128DB32 AVR128DB48 AVR128DB64
    AVR64DU28 AVR64DU32
  - Added support for AVR-Ex devices:
    AVR16EA28 AVR16EA32 AVR16EA48 AVR16EB14 AVR16EB20 AVR16EB28 AVR16EB32
    AVR32EA28 AVR32EA32 AVR32EA48 AVR64EA28 AVR64EA32 AVR64EA48
  - Added support for Reduced Tiny devices:
    ATiny102 ATtiny104
  - Added support for Classic devices:
    ATmega168PB ATmega328PB ATmega324PB
  - Added a new module to lib<mcu>.a that can be used as part of the
    startup code by the compiler.  The compiler will link the code when
    a device from the AVR-Dx or AVR-Ex families uses a non-default layout
    of NVMCTRL_CTRLB.FLMAP (Issue #931, Binutils PR31124, GCC PR112944).
    For more details on the feature see the GCC v14 release notes at
    https://gcc.gnu.org/gcc-14/changes.html#avr
  - Added support for: strndup.
  - Added support for: PROGMEM_FAR, PSTR_FAR, strchr_PF.
  - Added support for ccp_write_spm() in avr/cpufunc.h
  - The delay routines no more include math.h but use built-in functions
    __builtin_fabs and __builtin_ceil instead of fabs and ceil.  This means
    the delay routines are now independent of -f[no-]freestanding (Issue 580).
  - Added macros pgm_read_qword, pgm_read_qword_near, pgm_read_qword_far.
  - Added inline functions to read from progmem that return a type as
    indicated by the function name, like char pgm_read_char (const char*).
    The functions adjust to -mint8, -mdouble= and -mlong-double=.
    Functions for fixed-width types are pgm_read_i64, pgm_read_u24, etc.
  * Functions that read from beyond 64 KiB are suffixed _far and take
    an uint_farptr_t as argument.
  * pgm_read_float has been turned from a macro that takes uint16_t to
    an inline function that takes const float*.
  * pgm_read_byte, pgm_read_word and pgm_read_dword remain as they were
    and still take an uint16_t argument for compatibility and legacy code.
  - Added experimental templates pgm_read<> and pgm_read_far<>.  They are
    only available when macro __pgm_read_template__ is defined.
  - Added EEPROM support for: double, long double, uint64_t (*_qword).
  - AVR-LibC does not use section .progmem.* any more for lookup tables and
    string literals.  Instead, .progmemx.* is used which does not require
    that the data resides in the lower 64 KiB of program memory.
    This means that on devices with more than 64 KiB of program memory,
    the ELPM instruction is used to read the data where formerly it was LPM.
    Hence code size and execution times on such devices will slightly
    increase for functions from the printf and scanf families, and for libm
    functions that use power series.  (Issue #962).
    Notice that only since Binutils v2.29 (PR21849), section .progmemx is
    located after the .text sections.
  - The startup code now defines symbols like __DATA_REGION__LENGTH__ and
    __DATA_REGION_ORIGIN__ according to the memories of the used AVR device
    (Issue #936).  These symbols are used by the default linker scripts to
    diagnose when the text or data region overflows.
    To date, only a core specific default value was used, but the devices
    that belong to the same core architecture have different memory sizes.
  - The pgm_read_* and pgm_read_*_far macros and functions now also work for
    the Reduced Tiny devices. (Issue #563).  The implementation assumes that
    GCC implements PR71948 which was added in v7.  Notice that on Reduced Tiny:
  * There is no need for PROGEMM at all because all const objects in static
    storage are located in program memory since Binutils v2.27 (PR20849).
  * Even when PROGMEM is used, no pgm_read functions or macros are required.
    See the GCC documentation on the __progmem__ attribute for Reduced Tiny.
  * Issues closed:
  - [patch #9543] Add avrxmega3 devices. #824
  - [bug #49567] Use meta-info from --print-multi-lib and
  - -print-multi-directory #642
  - [bug #57071] Fix math.h and function names that block 64-bit
    double #670
  - Issue #476 [bug #32945] RAMPZ clobbered in far-pointer library.
    Functions from the far-pointer library in libc/pmstring like
    memcpy_PF that read from program memory using ELPM must set
    RAMPZ to the high byte of the 24-bit address.  On devices that
    don't use RAMPZ exclusively with ELPM, RAMPZ has to be reset when
    the function is finished.  These are devices with an EBI (External
    Bus Interface): ATxmega64A1, ATxmega64A1U, ATxmega128A1,
    ATxmega128A1U,  ATxmega128A4U.
  - Add device support to avr/power.h for:
    ATtiny441 ATtiny841
  - FDEV_SETUP_STREAM from stdio.h now works with C++ (Issue #898)
  - More than 80, mostly historic issues have been closed -- too many
    to mention all of them here
  - Fixed wrong prototypes of frexp, frexpf, frexpl in math.h (Issue #929)
  - time.h: function mktime() is off by 1h when [EU] DST is active (Issue #967)
  * Pull requests:
  - Logo [#969]
  - Documentation fixes [#968]
  - Issue #962 - libm: Use ELPM for tables on ELPM devices. [#964]
  - Issue #934: Fix EEPROM write issue on AVR-Ex and AVR-Dx family [#948]
  - Add code to initialize NVMCTRL_CTRLB.FLMAP in new module flmap-init.S enhancement [#947]
  - Add AVR-Ex devices enhancement [#946]
  - Issue 940 runtest [#941]
  - include/avr/io*.h: Update I/O header files enhancement [#938]
  - Issue #936: Provide symbols for exact memory layout. enhancement [#937]
  - Issue #931: Initialize NVMCTRL_CTRLB.FLMAP for Devices that have it. enhancement [#935]
  - Issue #931: Initialize NVMCTRL_CTRLB.FLMAP for Devices that have it. [#933]
  - Issue 929: Remove __ATTR_CONST__ from frexp* protoypes in math.h. [#932]
  - #890 #884: Fix / add entries for ATmega808/9, ATmega1608/9, ATmega3… [#927]
  - #921: Use all h files of $srcdir/include/avr in Makefile.am. enhancement [#925]
  - #892: configure.ac has outdated CHECK_AVR_DEVICE and AM_CONDITIONAL l… [#924]
  - avrxmega3: fix header installation for attiny424 [#921]
  - Rename aux.c to _aux_.c duplicate [#920]
  - iom32u4.h #define USBRF 5 [#919]
  - memory: Allow the use of stdint types [#918]
  - doc: Note attiny9 being supported documentation [#915]
  - Fix __BOOT_SIGROW_READ for some ATtiny [#914]
  - .githud [#908]
  - Extend _delay_loop_2 so it works with AVR_TINY. [#902]
  - Fix inline asm constraints of wdt_enable, wdt_disable. [#901]
  - Use autotools to determine Python command to run mlib-gen.py. [#896]
  - Issue #894: Remove scripts that make binary distributions and RPMs. [#895]
  - Fix issue #892: [#893]
  - Fix some avrxmega3 device names of generated files [#885]
  - .gitignore: Add outputs of ./boostrap [#883]
  - *.py: Use python3 instead of python [#882]
  - Added support for AVR-DA and DB devices [#881]
  - README.md: fix typo in URL [#873]
- Add patches to fix building man pages:
  * 0001-Return-files-missed-in-the-release-tarball.patch
  * 0002-dox_latex_header.tex-Add-to-EXTRA_DIST-969-1023.patch
  * 0003-dox-api-Makefile.am-EXTRA_DIST-Add-filter-dox.sh-avr.patch
* Thu Nov 10 2022 Klaus Kämpf <kkaempf@suse.com>
- update to 2.1.0
  * Improvements and additions:
  - Patch #9187 improved the library coverage for the AVR_TINY
    architecture (ATtiny10 and relatives).  In particular, many
    of the functions from <string.h> are now available there.
  - Patch #8729 adds ISR_NOICF and ISR_FLATTEN to <avr/interrupt.h>
  * Bugs fixed:
    [#36933] Documentation no longer correctly describes how to declare
    [#41689] add static_assert to assert.h
    [#48898] power_usart3_* functions no more defined in power.h
    [#49020] dtostre() flags documentation error
    [#49447] Example code for uart_putchar() has error in recursive call
    strings for storage in program memory
    [#50439] avr/iom32u4.h does not define PRTIM4
    [#51755] iotn441.h & iotn841.h missing definitions for PUEA[0-7] and PUEB[0-3]
    [no-id] util/eu_dst.h: fix reversed DST decision logic for March and October
    [no-id] util/delay.h.in: add missing return
  * Contributed Patches:
    [no-id] Define weak symbols for known memory region sizes based on device
    header definitions, starting with fuse region.
    [#8961] Update test script for new simulavr and library layout
    [#8964] Update tests isinf-01.c, signbit-01.c and modf-np.c
    [#9163] New eeprom write block function for xmega using eeprom page write
    [#8729] [avr/interrupt.h] Add ISR_NOICF, ISR_FLATTEN. Fix namespace
    of identifiers.
    [#8536] Fix a typo within <stdio.h>
    [#8649] small documentation fixes in
    [#9187] [AVR_TINY]: Support 16-bit xtoa functons and more string functions.
    [#9400] Add avrxmega3 multilibs
    [#9659] Update eeprom_is_ready for avrxmega3 devices
    [#9553] Fix some issues in libc/
    [#9864] Use proper float function names and prototypes
* Thu Feb 15 2018 rguenther@suse.com
- Remove setBadness from avr-libc-rpmlintrc, filter also errors
* Tue Dec 12 2017 kkaempf@suse.com
- fix Leap 42.x build: define gcc_version 7
* Tue Dec 12 2017 rguenther@suse.com
- Adjust sysroot to /usr/avr/sys-root as agreed upon by gcc and binutils.
* Tue Dec 12 2017 rguenther@suse.com
- Fix gcc dependences to use %%gcc_version.
- Remove install dependences on cross-avr-gcc and cross-avr-binutils.
* Tue Dec 12 2017 kkaempf@suse.com
- build with cross-avr-gcc7-bootstrap (bsc#1072028)
* Sat Dec  9 2017 kkaempf@suse.com
- build with cross-avr-gcc7
* Thu Dec  7 2017 kkaempf@suse.com
- symlink /opt/cross/avr/bin to /usr/avr/bin to make gcc use
  avr-as instead of as.
* Mon Feb  6 2017 duwe@suse.com
- update to 2.0.0
- remove old gcc-4.7 spec file
- fix prefix
- update some self tests to v2.0 tree structure
* Wed Jun 17 2015 sbrabec@suse.com
- Update to version 1.8.1.
- Drop patches:
  * 41-avr-libc-1.7.1-xmega32X1.patch: introduces just empty header
  * 42-avr-libc-1.7.1-xmega128b1.patch: now upstreamed
- Add PDF doc.
- Add GPG keys.
- Clean spec file.
* Tue May 26 2015 seife+obs@b1-systems.com
- add hack to add -pipe to avr-gcc calls
  this avoids changing temporary filenames embedded in binaries and
  thus continous republishing due to changed binaries
* Sat Dec  8 2012 jw@suse.com
- update to 1.8.0, bugfix release, including:
  PSTR() now has const, to be compatible with gcc-4.7.0
  savannah32698-power.patch upstreamed, removed.
- updated logicp to 1.02 to heal poisoned
  SIG_UART_RECV ==> UART_RX_vect and friends.
- added avr-libc-gcc47.spec to build with the new compiler.
* Tue Feb  7 2012 max@suse.com
- Make the dependency on cross-avr-binutils unversioned.
* Mon Mar  7 2011 jw@novell.com
- testcase for tn4313 added, non-fatal. Still fails due to missing gcc binutils support
- added savannah32698-power.patch
- update to 1.7.1
  This is primarily a bugfix release, and particularly, it fixes the infamous
  delay.h bug that caused the delay algorithm to be way off
  (https://savannah.nongnu.org/bugs/?30363).
* Mon Nov 29 2010 jw@novell.com
- fixed bnc#233520
* Tue Jun 22 2010 max@suse.de
- update to 1.7.0
  * New architecture: avrtiny10
  * New devices: atmega3000, attiny84a, atmega325a, atmega3250a,
    atmega329a, atmega3290a, attiny4, attiny5, attiny9, attiny10,
    attiny20, attiny40, ATxmega128A1U, ATxmega64A1U
  * countless bugfixes and other improvements
* Tue Mar 23 2010 jw@novell.com
- moved avr-example sub package into an own package.
  logicp remains here as a pre-install self-test.
* Sun Mar  7 2010 jw@novell.com
- do not require cross-acr-gcc44, we have removed the version number from the package.
* Mon Mar  1 2010 jw@novell.com
- update to 1.6.8
  * Added iox128a1u.h iom16hva2.h iom16hvb.h iom169pa.h iom649p.h iom64hve.h
    iotn261a.h iotn461a.h iotn861a.h iom324pa.h iotn10.h iotn4.h iotn5.h iotn9.h
    iom16a.h iom88pa.h iom644pa.h iotn24a.h iotn44a.h iotn2313a.h iotn4313.h
    iom8u2.h iom16u2.h iom32u2.h iox192d3.h
  * Add support for new devices: ATmega16HVA2, ATmega16HVB, ATmega48A,
    ATmega88A, ATmega168A, ATmega328, ATmega164A, ATmega324A, ATmega644A,
    ATmega165A, ATmega169A, ATmega645A, ATmega6450A, ATmega649A,
    ATmega6490A, ATmega6490P, ATmega645P, ATmega6450P, ATmega329PA.
    ATtiny2313A, ATtiny4313, ATtiny24A, ATtiny44A, ATmega644PA, ATmega88PA,
    ATmega16A, ATtiny261A, ATtiny861A, ATtiny461A, ATmega64HVE, ATmega169PA,
    ATmega649P, ATmega324PA.  ATmega8U2, ATmega16U2, and ATmega32U2.
    ATxmega192D3.
  * Add new functions: strtok_P() and strtok_rP(). memccpy_P().
  * Fix some tests to run with host computer.
  * several bugfixes.
* Sun Feb  7 2010 jw@novell.com
- updated avr_isp.pl to 0.9h,
  this now better handles a lrger range of dongles.
* Fri Jan 22 2010 jw@suse.de
- moved /usr/share/doc/avr-libc to /usr/share/doc/packages/avr-libc .
- populated /usr/bin/avr* symlinks, adding /opt/cross/bin to PATH no longer needed.
- added an 00_index.html to the user_manual.
* Tue Jan 19 2010 jw@suse.de
- rediffed patch to remove fuzz.
  pampered rpmlint warnings.
* Sun Aug  9 2009 jw@suse.de
- updated avr_common.mk to no longer rename dir if under svn
- update to 1.6.7,
  new devices  xmega192D3,mega8U2,mega16U2,ATmega32U2.
  various bugfixes. see
  http://cvs.savannah.gnu.org/viewvc/*checkout*/avr-libc/avr-libc/ChangeLog
* Fri Aug  7 2009 jw@suse.de
- updated avr_isp.pl to survive (unsigned char) casts,
  and give better diagnostics in case something else fails.
* Wed May 20 2009 jw@suse.de
- added a symlink so that html doku finds its examples.
* Sun Apr 26 2009 jw@suse.de
- updated to 1.6.6
  Too many small changes to list here. See
  http://cvs.savannah.gnu.org/viewvc/*checkout*/avr-libc/avr-libc/ChangeLog
* Wed Jan 30 2008 jw@suse.de
- update to 1.6.1
  * The fplib/math library is completely rewritten.
  * Functions of numbers to ascii conversion are completely rewritten.
  * Test suite is added to the Avr-libc project.
  * A few new util's headers: util/atomic.h, util/setbaud.h.
  * Many new devices added, many revised.
* Sat Oct 13 2007 bwalle@suse.de
- update to 1.4.6
  o Exclude 64-bit types for -mint8 (obsoletes no64bit_int.patch)
  o varios bugfixes (upstream #18115, #18385, #18509, #18662,
    [#18686], #18688, #18726, #18899, #18903, #18915, #19009, #19050,
    [#19060], #19134, #19135, #19280, #19281, #19445, #19495, #19650,
    [#19666] #19841)
  o new devices: AT90USB82, AT90USB162, ATmega325P, ATmega3250P,
    ATmega329P, ATmega3290P, AT90PWM1, ATmega8HVA, ATmega16HVA
  o The "largedemo" has been ported to the ATtiny2313.
  o Integrate a copy of the license file into the documentation.
  o Include an alphabetical index of all globals
  o Added 'avr25' architecture.
  o new functions (memchr_P, memcmp_P, memmem, memmem_P, memrchr,
    memrchr_P, strcasestr, strcasestr_P, strchrnul, strchrnul_P,
    strchr_P, strcspn, strcspn_P, strpbrk, strpbrk_P, strrchr_P,
    strsep_P, strspn, strspn_P)
  o Optimized functions (atoi, atol, strchr, strcmp, strcmp_P,
    strlwr, strrev, strsep, strstr, strstr_P, strupr)
* Thu Apr  5 2007 jw@suse.de
- gzipped manpages to make rpmlint happy.
  user-manual moved *into* /usr/share/doc/packages/avr-libc.
* Mon Jan 15 2007 jw@suse.de
- 64bit datatypes on 64bit hosts only fail with -mint8
  Now properly ifdefed.
* Tue Jan  9 2007 jw@suse.de
- update to 1.4.5
  ATmega165P/169P support. Fixes to the HD44780 driver.
  Power Management API. New "asmdemo" example.
  sleep.h: Fix the entry for the ATtiny2313.
  new devices: ATmega2560, ATmega2561.
  fp_split.S: Pop 3 bytes for avr6
  Bugs fixed: 15512 16125 16411 16434 16441
    16868 17068 17470 17551 17591 17608
- make test now tests 3 CPUs
* Tue Jan  9 2007 jw@suse.de
- compiling and linking my logicp application
  as a simple selftest.
- avr-64bit datatypes fail on 64bit hosts.
* Tue May 30 2006 jw@suse.de
- update to 1.4.4
  added /opt/cross/share/man/man3/* and /opt/cross/share/doc symlink
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 10 2006 jw@suse.de
- update to 1.4.2
* Wed Nov 23 2005 jw@suse.de
- upstreamed patches removed.
- update to 1.4.0
* Wed Oct  5 2005 dmueller@suse.de
- add norootforbuild
* Wed Aug 17 2005 jw@suse.de
- update to 1.2.5, fixes many things for atmega48
  e.g. [#105226].
* Tue May 17 2005 jw@suse.de
- removed dependency on uisp.
* Tue May 10 2005 jw@suse.de
- initial version: avr-libc-1.2.3
